/*
 *   IRC - Internet Relay Chat, src/modules/cloak.c
 *   (C) 2004 The UnrealIRCd Team
 *
 *   See file AUTHORS in IRC package for additional names of
 *   the programmers.
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 1, or (at your option)
 *   any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "config.h"
#include "struct.h"
#include "common.h"
#include "sys.h"
#include "numeric.h"
#include "msg.h"
#include "channel.h"
#include <time.h>
#include <sys/stat.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#ifdef _WIN32
#include <io.h>
#endif
#include <fcntl.h>
#include "h.h"
#ifdef _WIN32
#include "version.h"
#endif

DLLFUNC char *hidehost(char *host);
DLLFUNC char *cloakcsum();

Callback *cloak = NULL, *cloak_csum = NULL;

ModuleHeader MOD_HEADER(cloak)
  = {
  "nocloak",
  "nocloak.c, v 1.0.0.0 by Jason",
  "No Host Cloaking",
  "3.2-b8-1",
  NULL
  };

DLLFUNC int MOD_TEST(cloak)(ModuleInfo *modinfo)
{
	cloak = CallbackAddPCharEx(modinfo->handle, CALLBACKTYPE_CLOAK, hidehost);
	if (!cloak)
	{
		config_error("cloak: Error while trying to install cloaking callback!");
		return MOD_FAILED;
	}
	cloak_csum = CallbackAddPCharEx(modinfo->handle, CALLBACKTYPE_CLOAKKEYCSUM, cloakcsum);
	if (!cloak_csum)
	{
		config_error("cloak: Error while trying to install cloaking checksum callback!");
		return MOD_FAILED;
	}
	return MOD_SUCCESS;
}

DLLFUNC int MOD_INIT(cloak)(ModuleInfo *modinfo)
{
//	MARK_AS_OFFICIAL_MODULE(modinfo);  Not anymore!
	return MOD_SUCCESS;
}

DLLFUNC int MOD_LOAD(cloak)(int module_load)
{
	return MOD_SUCCESS;
}

DLLFUNC int MOD_UNLOAD(cloak)(int module_unload)
{
	return MOD_SUCCESS;
}

DLLFUNC char *hidehost(char *host)
{
	return host;
}

DLLFUNC char *cloakcsum()
{
static char cloak_checksum[64];

	ircsprintf(cloak_checksum, "RealHost");
        return cloak_checksum;
}
